@@ -2,7 +2,6 @@ package io.gitlab.arturbosch.detekt
 
 import io.gitlab.arturbosch.detekt.testkit.DslGradleRunner
 import io.gitlab.arturbosch.detekt.testkit.ProjectLayout
-import io.gitlab.arturbosch.detekt.testkit.createJavaClass
 import org.assertj.core.api.Assertions.assertThat
 import org.spekframework.spek2.Spek
 import org.spekframework.spek2.dsl.Skip
@@ -39,7 +38,6 @@ object DetektAndroidTest : Spek({
             }
             val gradleRunner = createGradleRunnerAndSetupProject(projectLayout)
             gradleRunner.writeProjectFile("app/src/main/AndroidManifest.xml", MANIFEST_CONTENT)
-            gradleRunner.createJavaClassAtSubmodule("AJavaClass")
 
             it("task :app:detektMain") {
                 gradleRunner.runTasksAndCheckResult(":app:detektMain") { buildResult ->
@@ -48,7 +46,6 @@ object DetektAndroidTest : Spek({
                     assertThat(buildResult.output).contains("--report xml:")
                     assertThat(buildResult.output).contains("--report sarif:")
                     assertThat(buildResult.output).doesNotContain("--report txt:")
-                    assertThat(buildResult.output).doesNotContain("AJavaClass.java")
                     assertThat(buildResult.tasks.map { it.path }).containsAll(
                         listOf(
                             ":app:detektMain",
@@ -66,7 +63,6 @@ object DetektAndroidTest : Spek({
                     assertThat(buildResult.output).contains("--report xml:")
                     assertThat(buildResult.output).contains("--report sarif:")
                     assertThat(buildResult.output).doesNotContain("--report txt:")
-                    assertThat(buildResult.output).doesNotContain("AJavaClassTest.java")
                     assertThat(buildResult.tasks.map { it.path }).containsAll(
                         listOf(
                             ":app:detektDebugUnitTest",
@@ -83,8 +79,6 @@ object DetektAndroidTest : Spek({
                     assertThat(buildResult.output).contains("--report xml:")
                     assertThat(buildResult.output).contains("--report sarif:")
                     assertThat(buildResult.output).doesNotContain("--report txt:")
-                    assertThat(buildResult.output).doesNotContain("AJavaClass.java")
-                    assertThat(buildResult.output).doesNotContain("AJavaClassTest.java")
                 }
             }
         }
@@ -148,7 +142,6 @@ object DetektAndroidTest : Spek({
             }
             val gradleRunner = createGradleRunnerAndSetupProject(projectLayout)
             gradleRunner.writeProjectFile("lib/src/main/AndroidManifest.xml", MANIFEST_CONTENT)
-            gradleRunner.createJavaClassAtSubmodule("AJavaClass")
 
             it("task :lib:detektMain") {
                 gradleRunner.runTasksAndCheckResult(":lib:detektMain") { buildResult ->
@@ -157,7 +150,6 @@ object DetektAndroidTest : Spek({
                     assertThat(buildResult.output).contains("--report xml:")
                     assertThat(buildResult.output).contains("--report sarif:")
                     assertThat(buildResult.output).doesNotContain("--report txt:")
-                    assertThat(buildResult.output).doesNotContain("AJavaClass.java")
                     assertThat(buildResult.tasks.map { it.path }).containsAll(
                         listOf(
                             ":lib:detektMain",
@@ -175,7 +167,6 @@ object DetektAndroidTest : Spek({
                     assertThat(buildResult.output).contains("--report xml:")
                     assertThat(buildResult.output).contains("--report sarif:")
                     assertThat(buildResult.output).doesNotContain("--report txt:")
-                    assertThat(buildResult.output).doesNotContain("AJavaClassTest.java")
                     assertThat(buildResult.tasks.map { it.path }).containsAll(
                         listOf(
                             ":lib:detektDebugUnitTest",
@@ -192,8 +183,6 @@ object DetektAndroidTest : Spek({
                     assertThat(buildResult.output).contains("--report xml:")
                     assertThat(buildResult.output).contains("--report sarif:")
                     assertThat(buildResult.output).doesNotContain("--report txt:")
-                    assertThat(buildResult.output).doesNotContain("AJavaClass.java")
-                    assertThat(buildResult.output).doesNotContain("AJavaClassTest.java")
                 }
             }
         }
@@ -467,7 +456,3 @@ private fun createGradleRunnerAndSetupProject(projectLayout: ProjectLayout) = Ds
     """.trimIndent(),
     dryRun = true
 ).also { it.setupProject() }
-
-private fun DslGradleRunner.createJavaClassAtSubmodule(name: String) {
-    createJavaClass(projectLayout.submodules.first(), name)
-}
