@@ -2,7 +2,6 @@ package io.gitlab.arturbosch.detekt
 
 import io.gitlab.arturbosch.detekt.testkit.DslGradleRunner
 import io.gitlab.arturbosch.detekt.testkit.ProjectLayout
-import io.gitlab.arturbosch.detekt.testkit.createJavaClass
 import org.assertj.core.api.Assertions.assertThat
 import org.spekframework.spek2.Spek
 import org.spekframework.spek2.style.specification.describe
@@ -35,7 +34,6 @@ object DetektJvmTest : Spek({
             dryRun = true
         )
         gradleRunner.setupProject()
-        gradleRunner.createJavaClass("AJavaClass")
 
         it("configures detekt type resolution task main") {
             gradleRunner.runTasksAndCheckResult(":detektMain") { buildResult ->
@@ -44,7 +42,6 @@ object DetektJvmTest : Spek({
                 assertThat(buildResult.output).contains("--report sarif:")
                 assertThat(buildResult.output).doesNotContain("--report txt:")
                 assertThat(buildResult.output).contains("--classpath")
-                assertThat(buildResult.output).doesNotContain("AJavaClass.java")
             }
         }
 
@@ -55,7 +52,6 @@ object DetektJvmTest : Spek({
                 assertThat(buildResult.output).contains("--report sarif:")
                 assertThat(buildResult.output).doesNotContain("--report txt:")
                 assertThat(buildResult.output).contains("--classpath")
-                assertThat(buildResult.output).doesNotContain("AJavaClassTest.java")
             }
         }
     }
