@@ -163,14 +163,7 @@ private fun FlowOrInteractiveContent.summary(
 private class SUMMARY(
     initialAttributes: Map<String, String>,
     override val consumer: TagConsumer<*>
-) : HTMLTag(
-    "summary",
-    consumer,
-    initialAttributes,
-    null,
-    false,
-    false
-),
+) : HTMLTag("summary", consumer, initialAttributes, null, false, false),
     CommonAttributeGroupFacadeFlowInteractiveContent
 
 private fun TextLocation.length(): Int = end - start
