@@ -12,9 +12,11 @@ class UnnecessaryInheritanceSpec : Spek({
     describe("check inherit classes") {
 
         it("has unnecessary super type declarations") {
-            val findings = subject.lint("""
+            val findings = subject.lint(
+                """
                 class A : Any()
-                class B : Object()""")
+                class B : Object()"""
+            )
             assertThat(findings).hasSize(2)
         }
 
