@@ -37,17 +37,19 @@ static iColor darkPalette_[] = {
     { 160, 160, 160, 255 },
     { 255, 255, 255, 255 },
 
-    { 106, 80,  0,   255 },
-    { 255, 192, 0,   255 },
+    { 98,  67,  7,   255 },
+    { 255, 170, 32,  255 },
     { 0,   96,  128, 255 },
     { 0,   192, 255, 255 },
-    
-    { 140, 32,  32,   255 },
-    { 255, 80, 80,  255 },
-    { 24,  80, 24,  255 },
+
+    { 140, 32,  32,  255 },
+    { 255, 80,  80,  255 },
+    { 24,  80,  24,  255 },
     { 48,  200, 48,  255 },
-    { 35,  50,  128, 255 },
-    { 92,  128,  255, 255 },
+    { 0,   70,  128, 255 },
+    { 40,  132, 255, 255 },
+    { 0,   0,   0,   0   },
+    { 0,   0,   0,   0   },
 };
 
 static iColor lightPalette_[] = {
@@ -61,13 +63,15 @@ static iColor lightPalette_[] = {
     { 235, 215, 200, 255 },
     { 10,  110, 130, 255 },
     { 170, 215, 220, 255 },
-    
-    { 150, 60,  55,   255 },
-    { 240, 180, 170,  255 },
-    { 50,   100, 50,  255 },
-    { 128,   200, 128,  255 },
-    { 80,   110,  190, 255 },
-    { 150,  192,  255, 255 },
+
+    { 150, 60,  55,  255 },
+    { 240, 180, 170, 255 },
+    { 50,  100, 50,  255 },
+    { 128, 200, 128, 255 },
+    { 50,  120, 190, 255 },
+    { 150, 211, 255, 255 },
+    { 0,   0,   0,   0   },
+    { 0,   0,   0,   0   },
 };
 
 static iColor uiPalette_[tmFirst_ColorId]; /* not theme-specific */
@@ -90,6 +94,7 @@ int color_ColorAccent(enum iColorAccent accent, iBool isBright) {
         green_ColorId,
         blue_ColorId,
         isMedium ? white_ColorId : gray75_ColorId,
+        systemHigh_ColorId,
     };
     const int darkColors[max_ColorAccent] = {
         teal_ColorId,
@@ -98,6 +103,7 @@ int color_ColorAccent(enum iColorAccent accent, iBool isBright) {
         darkGreen_ColorId,
         indigo_ColorId,
         isMedium ? black_ColorId : gray25_ColorId,
+        systemLow_ColorId,
     };
     return isBright ? brightColors[accent] : darkColors[accent];
 }
@@ -109,8 +115,16 @@ int accent_Color(iBool isBright) {
 void setThemePalette_Color(enum iColorTheme theme) {
     const iPrefs *prefs = prefs_App();
     memcpy(uiPalette_, isDark_ColorTheme(theme) ? darkPalette_ : lightPalette_, sizeof(darkPalette_));
-    const int accentHi = color_ColorAccent(prefs->accent, 1);
-    const int accentLo = color_ColorAccent(prefs->accent, 0);
+    /* Update the system accent color. */ {
+        const iBool isMediumDark = prefs_App()->theme == dark_ColorTheme;
+        iColor system = systemAccent_Color();
+        darkPalette_[systemHigh_ColorId]  = system;
+        darkPalette_[systemLow_ColorId]   = rgb_HSLColor(addSatLum_HSLColor(hsl_Color(system), 0, -0.25f));
+        lightPalette_[systemHigh_ColorId] = rgb_HSLColor(addSatLum_HSLColor(hsl_Color(system), 0, 0.3f));
+        lightPalette_[systemLow_ColorId]  = rgb_HSLColor(addSatLum_HSLColor(hsl_Color(system), 0, -0.1f));
+    }
+    const int accentHi = color_ColorAccent(prefs->accent, iTrue /* bright */);
+    const int accentLo = color_ColorAccent(prefs->accent, iFalse /* dim */);
     switch (theme) {
         case pureBlack_ColorTheme: {
             copy_(uiBackground_ColorId, black_ColorId);
@@ -154,7 +168,7 @@ void setThemePalette_Color(enum iColorTheme theme) {
             copy_(uiInputCursor_ColorId, accentHi);
             copy_(uiInputCursorText_ColorId, black_ColorId);
             copy_(uiHeading_ColorId, accentHi);
-            copy_(uiAnnotation_ColorId, accentLo);
+            copy_(uiAnnotation_ColorId, accentHi);
             copy_(uiIcon_ColorId, accentHi);
             copy_(uiIconHover_ColorId, accentHi);
             copy_(uiSeparator_ColorId, gray25_ColorId);
@@ -208,7 +222,7 @@ void setThemePalette_Color(enum iColorTheme theme) {
             copy_(uiInputCursor_ColorId, accentHi);
             copy_(uiInputCursorText_ColorId, black_ColorId);
             copy_(uiHeading_ColorId, accentHi);
-            copy_(uiAnnotation_ColorId, accentLo);
+            copy_(uiAnnotation_ColorId, accentHi);
             copy_(uiIcon_ColorId, accentHi);
             copy_(uiIconHover_ColorId, accentHi);
             copy_(uiSeparator_ColorId, black_ColorId);
@@ -364,7 +378,7 @@ iColor get_Color(int color) {
 }
 
 iColor default_Color(int color) {
-    if (color >= 0 && color < iElemCount(darkPalette_)) {
+    if (color >= 0 && color < (int) iElemCount(darkPalette_)) {
         return (isDark_ColorTheme(prefs_App()->theme) ? darkPalette_ : lightPalette_)[color];
     }
     return (iColor){ 0, 0, 0, 0 };
@@ -428,9 +442,32 @@ iLocalDef iColor toColor_(iFloat4 d) {
                      (uint8_t) w_F4(i) };
 }
 
+iLocalDef iColorf toColorf_(iFloat4 d) {
+    return (iColorf){ x_F4(d), y_F4(d), z_F4(d), w_F4(d) };
+}
+
+iLocalDef uint8_t quantize8_(float f) {
+    f = iClamp(f, 0.0f, 1.0f);
+    return (uint8_t) (f * 255.0f + 0.5f);
+}
+
+iColor uint8_Colorf(iColorf d) {
+    return toColor_(initv_F4(&d.r));
+}
+
+iColorf float_Color(iColor d) {
+    return (iColorf){ d.r / 255.0f, d.g / 255.0f, d.b / 255.0f, d.a / 255.0f };
+}
+
 iHSLColor hsl_Color(iColor color) {
-    float rgb[4];
-    store_F4(normalize_(color), rgb);
+    return hsl_Colorf(float_Color(color));
+}
+
+iHSLColor hsl_Colorf(iColorf color) {
+    const float rgb[4] = { iClamp(color.r, 0.0f, 1.0f),
+                           iClamp(color.g, 0.0f, 1.0f),
+                           iClamp(color.b, 0.0f, 1.0f),
+                           iClamp(color.a, 0.0f, 1.0f) };
     int compMax, compMin;
     if (rgb[0] >= rgb[1] && rgb[0] >= rgb[2]) {
         compMax = 0;
@@ -480,7 +517,7 @@ static float hueToRgb_(float p, float q, float t) {
     return p;
 }
 
-iColor rgb_HSLColor(iHSLColor hsl) {
+iColorf rgbf_HSLColor(iHSLColor hsl) {
     float r, g, b;
     hsl.hue /= 360.0f;
     hsl.hue = iWrapf(hsl.hue, 0, 1);
@@ -497,13 +534,25 @@ iColor rgb_HSLColor(iHSLColor hsl) {
         g = hueToRgb_(p, q, hsl.hue);
         b = hueToRgb_(p, q, hsl.hue - 1.0f / 3.0f);
     }
-    return toColor_(init_F4(r, g, b, hsl.a));
+    return toColorf_(init_F4(r, g, b, hsl.a));
+}
+
+iColor rgb_HSLColor(iHSLColor hsl) {
+    return uint8_Colorf(rgbf_HSLColor(hsl));
 }
 
 float luma_Color(iColor color) {
     return 0.299f * color.r / 255.0f + 0.587f * color.g / 255.0f + 0.114f * color.b / 255.0f;
 }
 
+float luma_Colorf(iColorf color) {
+    return 0.299f * color.r + 0.587f * color.g + 0.114f * color.b;
+}
+
+float luma_HSLColor(iHSLColor hsl) {
+    return luma_Color(rgb_HSLColor(hsl));
+}
+
 const char *escape_Color(int color) {
     static const char *esc[] = {
         black_ColorEscape,
@@ -967,7 +1016,7 @@ iBool loadPalette_Color(const char *path) {
                 { "black:", 0 }, { "gray25:", 1 }, { "gray50:", 2 }, { "gray75:", 3 },
                 { "white:", 4 }, { "brown:", 5 },  { "orange:", 6 }, { "teal:", 7 },
                 { "cyan:", 8 },  { "maroon:", 9 }, { "red:", 10 }, { "darkGreen:", 11 },
-                { "green:", 12 }, { "indigo:", 13 }, { "blue:", 14 }, 
+                { "green:", 12 }, { "indigo:", 13 }, { "blue:", 14 },
             };
             iForIndices(i, colors_) {
                 if (startsWithCase_Rangecc(line, colors_[i].label)) {
@@ -1011,6 +1060,6 @@ iBool loadPalette_Color(const char *path) {
 
 #if !defined (iPlatformAppleDesktop)
 iColor systemAccent_Color(void) {
-    return (iColor){ 255, 255, 255, 255 };
+    return darkPalette_[cyan_ColorId];
 }
 #endif
